==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkWindowToImageFilter.java <==
// java wrapper for vtkWindowToImageFilter object
//

package vtk;
import vtk.*;

public class vtkWindowToImageFilter extends vtkAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInput_2(vtkWindow id0);
  public void SetInput(vtkWindow id0)
    { SetInput_2(id0); }

  private native long GetInput_3();
  public vtkWindow GetInput() {
    long temp = GetInput_3();

    if (temp == 0) return null;
    return (vtkWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetMagnification_4(int id0);
  public void SetMagnification(int id0)
    { SetMagnification_4(id0); }

  private native int GetMagnificationMinValue_5();
  public int GetMagnificationMinValue()
    { return GetMagnificationMinValue_5(); }

  private native int GetMagnificationMaxValue_6();
  public int GetMagnificationMaxValue()
    { return GetMagnificationMaxValue_6(); }

  private native int GetMagnification_7();
  public int GetMagnification()
    { return GetMagnification_7(); }

  private native void SetFixBoundary_8(boolean id0);
  public void SetFixBoundary(boolean id0)
    { SetFixBoundary_8(id0); }

  private native boolean GetFixBoundary_9();
  public boolean GetFixBoundary()
    { return GetFixBoundary_9(); }

  private native void FixBoundaryOn_10();
  public void FixBoundaryOn()
    { FixBoundaryOn_10(); }

  private native void FixBoundaryOff_11();
  public void FixBoundaryOff()
    { FixBoundaryOff_11(); }

  private native void ReadFrontBufferOn_12();
  public void ReadFrontBufferOn()
    { ReadFrontBufferOn_12(); }

  private native void ReadFrontBufferOff_13();
  public void ReadFrontBufferOff()
    { ReadFrontBufferOff_13(); }

  private native int GetReadFrontBuffer_14();
  public int GetReadFrontBuffer()
    { return GetReadFrontBuffer_14(); }

  private native void SetReadFrontBuffer_15(int id0);
  public void SetReadFrontBuffer(int id0)
    { SetReadFrontBuffer_15(id0); }

  private native void ShouldRerenderOn_16();
  public void ShouldRerenderOn()
    { ShouldRerenderOn_16(); }

  private native void ShouldRerenderOff_17();
  public void ShouldRerenderOff()
    { ShouldRerenderOff_17(); }

  private native void SetShouldRerender_18(int id0);
  public void SetShouldRerender(int id0)
    { SetShouldRerender_18(id0); }

  private native int GetShouldRerender_19();
  public int GetShouldRerender()
    { return GetShouldRerender_19(); }

  private native void SetViewport_20(double id0,double id1,double id2,double id3);
  public void SetViewport(double id0,double id1,double id2,double id3)
    { SetViewport_20(id0,id1,id2,id3); }

  private native void SetViewport_21(double id0[]);
  public void SetViewport(double id0[])
    { SetViewport_21(id0); }

  private native double[] GetViewport_22();
  public double[] GetViewport()
    { return GetViewport_22(); }

  private native void SetInputBufferType_23(int id0);
  public void SetInputBufferType(int id0)
    { SetInputBufferType_23(id0); }

  private native int GetInputBufferType_24();
  public int GetInputBufferType()
    { return GetInputBufferType_24(); }

  private native void SetInputBufferTypeToRGB_25();
  public void SetInputBufferTypeToRGB()
    { SetInputBufferTypeToRGB_25(); }

  private native void SetInputBufferTypeToRGBA_26();
  public void SetInputBufferTypeToRGBA()
    { SetInputBufferTypeToRGBA_26(); }

  private native void SetInputBufferTypeToZBuffer_27();
  public void SetInputBufferTypeToZBuffer()
    { SetInputBufferTypeToZBuffer_27(); }

  private native long GetOutput_28();
  public vtkImageData GetOutput() {
    long temp = GetOutput_28();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkWindowToImageFilter() { super(); }

  public vtkWindowToImageFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-21-aarch64.pkg.tar.xz: vtk/vtkWindowToImageFilter.java <==
// java wrapper for vtkWindowToImageFilter object
//

package vtk;
import vtk.*;

public class vtkWindowToImageFilter extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInput_2(vtkWindow id0);
  public void SetInput(vtkWindow id0)
    { SetInput_2(id0); }

  private native long GetInput_3();
  public vtkWindow GetInput() {
    long temp = GetInput_3();

    if (temp == 0) return null;
    return (vtkWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScale_4(int id0,int id1);
  public void SetScale(int id0,int id1)
    { SetScale_4(id0,id1); }

  private native void SetScale_5(int id0[]);
  public void SetScale(int id0[])
    { SetScale_5(id0); }

  private native int[]  GetScale_6();
  public int[]  GetScale()
    { return GetScale_6(); }

  private native void SetScale_7(int id0);
  public void SetScale(int id0)
    { SetScale_7(id0); }

  private native void SetFixBoundary_8(boolean id0);
  public void SetFixBoundary(boolean id0)
    { SetFixBoundary_8(id0); }

  private native boolean GetFixBoundary_9();
  public boolean GetFixBoundary()
    { return GetFixBoundary_9(); }

  private native void FixBoundaryOn_10();
  public void FixBoundaryOn()
    { FixBoundaryOn_10(); }

  private native void FixBoundaryOff_11();
  public void FixBoundaryOff()
    { FixBoundaryOff_11(); }

  private native void ReadFrontBufferOn_12();
  public void ReadFrontBufferOn()
    { ReadFrontBufferOn_12(); }

  private native void ReadFrontBufferOff_13();
  public void ReadFrontBufferOff()
    { ReadFrontBufferOff_13(); }

  private native int GetReadFrontBuffer_14();
  public int GetReadFrontBuffer()
    { return GetReadFrontBuffer_14(); }

  private native void SetReadFrontBuffer_15(int id0);
  public void SetReadFrontBuffer(int id0)
    { SetReadFrontBuffer_15(id0); }

  private native void ShouldRerenderOn_16();
  public void ShouldRerenderOn()
    { ShouldRerenderOn_16(); }

  private native void ShouldRerenderOff_17();
  public void ShouldRerenderOff()
    { ShouldRerenderOff_17(); }

  private native void SetShouldRerender_18(int id0);
  public void SetShouldRerender(int id0)
    { SetShouldRerender_18(id0); }

  private native int GetShouldRerender_19();
  public int GetShouldRerender()
    { return GetShouldRerender_19(); }

  private native void SetViewport_20(double id0,double id1,double id2,double id3);
  public void SetViewport(double id0,double id1,double id2,double id3)
    { SetViewport_20(id0,id1,id2,id3); }

  private native double[] GetViewport_21();
  public double[] GetViewport()
    { return GetViewport_21(); }

  private native void SetInputBufferType_22(int id0);
  public void SetInputBufferType(int id0)
    { SetInputBufferType_22(id0); }

  private native int GetInputBufferType_23();
  public int GetInputBufferType()
    { return GetInputBufferType_23(); }

  private native void SetInputBufferTypeToRGB_24();
  public void SetInputBufferTypeToRGB()
    { SetInputBufferTypeToRGB_24(); }

  private native void SetInputBufferTypeToRGBA_25();
  public void SetInputBufferTypeToRGBA()
    { SetInputBufferTypeToRGBA_25(); }

  private native void SetInputBufferTypeToZBuffer_26();
  public void SetInputBufferTypeToZBuffer()
    { SetInputBufferTypeToZBuffer_26(); }

  private native long GetOutput_27();
  public vtkImageData GetOutput() {
    long temp = GetOutput_27();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkWindowToImageFilter() { super(); }

  public vtkWindowToImageFilter(long id) { super(id); }
  public native long   VTKInit();

}
